pub enum Error {
OutputTooSmall,
InputTruncated,
Unsupported,
InvalidConfig,
}Expand description
JPEG driver errors.
Variants
OutputTooSmall
Output buffer is smaller than the produced JPEG / decoded image.
InputTruncated
Input ended before the codec consumed enough data to finish.
Unsupported
JPEG features that aren’t supported (progressive, 12-bit, RGB/CMYK source, etc).
InvalidConfig
Encode parameters are invalid (zero dimensions, out-of-range quality, dimensions not a multiple of the MCU size, mismatched buffer sizes, etc).